@@ -71,7 +71,10 @@ sub new {
 
     # If we're fully authed (i.e username and password ) then we need to log in
     my $res = $self->_ua->_post('/login', {}, user => $self->{user}, password => $self->{password});
-    die "Unauthorized" unless $res->is_success;
+    unless ($res->is_success) {
+        die "You must have IO::Socket::SSL or Crypt::SSLeay installed in order to do SSL requests\n" if $res->code == 501 && $res->status_line =~ /Protocol scheme 'https' is not supported/;
+        die "Unauthorized" unless $res->is_success;
+    }
     my $content = $self->_json->from_json($res->decoded_content);    
     $self->{_cookie} = $res->header('set-cookie');
     return wantarray ? ($self, $content->{user}, $content->{customer}) : $self;
@@ -114,6 +117,14 @@ sub set_customer {
 }
 
 
+# Get stuff from the stats API
+sub _get_stats {
+    my $self    = shift;
+    my $content = $self->_get(@_);
+    die $content->{msg} unless $content->{status} eq 'success';
+    return $content->{data};
+}
+
 sub _get {
     my $self = shift;
     my $path = shift;
@@ -245,7 +256,7 @@ sub _make_url {
 
     my $prot = "https:";
     if ($base =~ s!^(https?:)//!!) {
-	$prot = $1;
+        $prot = $1;
     }
     my $url = URI->new($prot);
     $url->host($base);
@@ -276,6 +287,7 @@ sub _make_params {
 package Net::Fastly::UA;
 
 use base qw(LWP::UserAgent);
+use LWP::Protocol::https;
 our $DEBUG=0;
 
 sub request {
